/* config-kwindowsystem.h. Generated by cmake from config-kwindowsystem.h.cmake */

/* Define to 1 if you have the Xlib */
#define KWINDOWSYSTEM_HAVE_X11 1

/* Define to 1 if you have the Xfixes library */
#define KWINDOWSYSTEM_HAVE_XFIXES 1

/* Path to xcb plugin */
#define XCB_PLUGIN_PATH "/usr/local/lib/qt5/plugins/kf5/kwindowsystem/KF5WindowSystemX11Plugin.so"
